@@ -112,7 +112,7 @@ class TRMaid(object):
 
     def verbose_func(self, func, *args):
         if self.verbose:
-            print ('%s(%s)' % (
+            print('%s(%s)' % (
                 func.__name__,
                 ', '.join([json.dumps(x, indent=2) for x in args]),
             ), end='')
@@ -407,15 +407,10 @@ class TRMaid(object):
             if rdskey and result in ['success', 'duplicate torrent']:
                 self.rds.lpush(rdskey, xhash)
 
-            if result != 'success':
-                continue
-
             arguments = res.get('arguments', {})
-
-            if arguments.get('torrent-added', None):
+            if 'torrent-added' in arguments:
                 ids.append(arguments['torrent-added']['id'])
 
-
         if ids:
             if rdskey:
                 self.rds.ltrim(rdskey, 0, 1000)
